@@ -8,7 +8,7 @@ package Future::AsyncAwait;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Carp;
 
@@ -149,6 +149,13 @@ Most cases involving awaiting on still-pending futures should work fine:
       }
    }
 
+   async sub quux
+   {
+      my $x = do {
+         await func();
+      };
+   }
+
    async sub splat
    {
       eval {
@@ -239,6 +246,19 @@ As of C<Future::AsyncAwait> version 0.10 and L<Syntax::Keyword::Try> version
 inside an C<async sub> work correctly, including those that attempt to
 C<return> from inside C<try>.
 
+   use Syntax::Keyword::Try;
+
+   async sub attempt
+   {
+      try {
+         await func();
+         return "success";
+      }
+      catch {
+         return "failed";
+      }
+   }
+
 =cut
 
 sub import
@@ -304,7 +324,7 @@ L<https://rt.cpan.org/Ticket/Display.html?id=122252>
 
 Support sub signatures in recent perls.
 
-L<https://rt.cpan.org/Ticket/Display.html?id=124122>
+L<https://rt.cpan.org/Ticket/Display.html?id=123465>
 
 =back
 
